OC.L10N.register(
    "files",
    {
    "File could not be found" : "Nie można znaleźć pliku",
    "Move or copy" : "Przenieś lub kopiuj",
    "Download" : "Pobierz",
    "Delete" : "Usuń",
    "Tags" : "Etykiety",
    "Show list view" : "Pokaż widok listy",
    "Show grid view" : "Pokaż widok siatki",
    "Home" : "Strona główna",
    "Close" : "Zamknij",
    "Favorites" : "Ulubione",
    "Could not create folder \"{dir}\"" : "Nie można utworzyć katalogu \"{dir}\"",
    "This will stop your current uploads." : "Spowoduje to zatrzymanie wysyłania plików.",
    "Upload cancelled." : "Wysyłanie anulowane.",
    "Processing files …" : "Przetwarzam pliki…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nie można wysłać {filename} być może jest katalogiem lub posiada 0 bajtów",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Brak wolnej przestrzeni, wysyłasz {size1} a pozostało tylko {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Katalog docelowy \"{dir}\" już nie istnieje",
    "Not enough free space" : "Za mało wolnego miejsca",
    "An unknown error has occurred" : "Wystąpił nieznany błąd",
    "File could not be uploaded" : "Nie można przesłać pliku",
    "Uploading …" : "Wysyłanie…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Wysyłanie tego elementu nie jest wspierane",
    "Target folder does not exist any more" : "Katalog docelowy już nie istnieje",
    "Operation is blocked by access control" : "Operacja jest zablokowana przez kontrolę dostępu",
    "Error when assembling chunks, status code {status}" : "Błąd podczas łączenia fragmentów, kod statusu {status}",
    "Actions" : "Akcje",
    "Rename" : "Zmień nazwę",
    "Move" : "Przenieś",
    "Copy" : "Kopiuj",
    "Choose target folder" : "Wybierz katalog docelowy",
    "Edit locally" : "Edytuj lokalnie",
    "Open" : "Otwórz",
    "Delete file" : "Usuń plik",
    "Delete folder" : "Usuń katalog",
    "Disconnect storage" : "Odłącz magazyn",
    "Leave this share" : "Opuść udostępnienie",
    "Could not load info for file \"{file}\"" : "Nie można załadować informacji o pliku \"{file}\"",
    "Files" : "Pliki",
    "Details" : "Szczegóły",
    "Please select tag(s) to add to the selection" : "Wybierz etykietę(y) do dodania dla zaznaczenia",
    "Apply tag(s) to selection" : "Zastosuj etykietę(y) dla zaznaczenia",
    "Select directory \"{dirName}\"" : "Wybierz katalog \"{dirName}\"",
    "Select file \"{fileName}\"" : "Wybierz plik \"{fileName}\"",
    "Pending" : "Oczekujące",
    "Unable to determine date" : "Nie można ustalić daty",
    "This operation is forbidden" : "Ta operacja jest niedozwolona",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ten katalog jest niedostępny, sprawdź logi lub skontaktuj się z administratorem",
    "Storage is temporarily not available" : "Magazyn jest tymczasowo niedostępny",
    "Could not move \"{file}\", target exists" : "Nie można przenieść \"{file}\" - plik o takiej nazwie już istnieje",
    "Could not move \"{file}\"" : "Nie można przenieść \"{file}\"",
    "copy" : "kopia",
    "Could not copy \"{file}\", target exists" : "Nie można skopiować \"{file}\", plik już istnieje",
    "Could not copy \"{file}\"" : "Nie można skopiować \"{file}\"",
    "Copied {origin} inside {destination}" : "Skopiowano {origin} wewnątrz {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Skopiowano {origin} oraz {nbfiles} innych plików wewnątrz {destination}",
    "Failed to redirect to client" : "Nie udało się przekierować do klienta",
    "{newName} already exists" : "{newName} już istnieje",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nie można zmienić nazwy \"{fileName}\", plik już nie istnieje",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nazwa \"{targetName}\" jest już używana w katalogu \"{dir}\". Wybierz inną nazwę.",
    "Could not rename \"{fileName}\"" : "Nie można zmienić nazwy \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nie można utworzyć pliku \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nie można utworzyć pliku \"{file}\", ponieważ ten plik już istnieje.",
    "Could not create folder \"{dir}\" because it already exists" : "Nie można utworzyć katalogu \"{dir}\", ponieważ już istnieje",
    "Could not fetch file details \"{file}\"" : "Nie można pobrać szczegółów pliku \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Błąd podczas usuwania pliku \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Brak wyników wyszukiwania w innych katalogach dla {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Wprowadź więcej niż dwa znaki, aby przeszukać inne katalogi",
    "Name" : "Nazwa",
    "Size" : "Rozmiar",
    "Modified" : "Zmodyfikowany",
    "_%n folder_::_%n folders_" : ["%n katalog","%n katalogi","%n katalogów","%n katalogów"],
    "_%n file_::_%n files_" : ["%n plik","%n pliki","%n plików","%n plików"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "_including %n hidden_::_including %n hidden_" : ["w tym %n ukryty","w tym %n ukryte","w tym %n ukrytych","w tym %n ukrytych"],
    "You do not have permission to upload or create files here" : "Nie masz uprawnień do wysyłania lub tworzenia plików w tym miejscu",
    "_Uploading %n file_::_Uploading %n files_" : ["Wysyłanie %n pliku","Wysyłanie %n plików","Wysyłanie %n plików","Wysyłanie %n plików"],
    "New file/folder menu" : "Nowe menu plików/katalogów",
    "Select file range" : "Wybierz zakres plików",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "Wykorzystane {used} z {quota}",
    "{used} used" : "Wykorzystane {used}",
    "\"{name}\" is an invalid file name." : "\"{name}\" jest nieprawidłową nazwą pliku.",
    "File name cannot be empty." : "Nazwa pliku nie może być pusta.",
    "\"/\" is not allowed inside a file name." : "Znak \"/\" jest niedozwolony w nazwie pliku.",
    "\"{name}\" is not an allowed filetype" : "typ pliku \"{name}\" jest niedozwolony",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Magazyn dla {owner} jest pełny. Nie można już aktualizować ani synchronizować plików!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Katalog grupowy \"{mountPoint}\" jest pełny. Nie można już aktualizować ani synchronizować plików!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Magazyn zewnętrzny \"{mountPoint}\" jest pełny. Nie można już aktualizować ani synchronizować plików!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Magazyn jest pełny. Nie można już zaktualizować ani zsynchronizować plików!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Magazyn dla {owner} jest pawie pełny ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Katalog grupowy \"{mountPoint}\" jest prawie pełny ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Pamięć zewnętrzna \"{mountPoint}\" jest prawie pełna ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Twój magazyn jest prawie pełny ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["pasuje do \"{filter}\"","pasują do \"{filter}\"","pasują do \"{filter}\"","pasują do \"{filter}\""],
    "View in folder" : "Zobacz w katalogu",
    "Direct link was copied (only works for users who have access to this file/folder)" : "Bezpośredni link został skopiowany (działa tylko dla użytkowników, którzy mają dostęp do tego pliku/katalogu)",
    "Path" : "Ścieżka",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtów","%n bajtów"],
    "Favorited" : "Ulubiony",
    "Favorite" : "Ulubiony",
    "Copy direct link (only works for users who have access to this file/folder)" : "Skopiuj bezpośredni link (działa tylko dla użytkowników, którzy mają dostęp do tego pliku/katalogu)",
    "You can only favorite a single file or folder at a time" : "Możesz dodać do ulubionych tylko pojedynczy plik lub katalog",
    "New folder" : "Nowy katalog",
    "Upload file" : "Wyślij plik",
    "Recent" : "Ostatnie",
    "Not favorited" : "Wyłączone z ulubionych",
    "Remove from favorites" : "Usuń z ulubionych",
    "Add to favorites" : "Dodaj do ulubionych",
    "An error occurred while trying to update the tags" : "Wystąpił błąd podczas próby aktualizacji etykiet",
    "Added to favorites" : "Dodano do ulubionych",
    "Removed from favorites" : "Usunięto z ulubionych",
    "You added {file} to your favorites" : "Dodałeś {file} do ulubionych",
    "You removed {file} from your favorites" : "Usunąłeś {file} z ulubionych",
    "File changes" : "Zmiany w plikach",
    "Created by {user}" : "Utworzone przez {user}",
    "Changed by {user}" : "Zmienione przez {user}",
    "Deleted by {user}" : "Usunięte przez {user}",
    "Restored by {user}" : "Przywrócone przez {user}",
    "Renamed by {user}" : "Zmienione przez {user}",
    "Moved by {user}" : "Przeniesione przez {user}",
    "\"remote user\"" : "\"użytkownik zdalny\"",
    "You created {file}" : "Utworzy‭łeś {file}",
    "You created an encrypted file in {file}" : "Stworzyłeś zaszyfrowany plik w {file}",
    "{user} created {file}" : "{user} utworzy‭ł {file}",
    "{user} created an encrypted file in {file}" : "{user} utworzył zaszyfrowany plik w {file}",
    "{file} was created in a public folder" : "{file} został utworzony w katalogu publicznym",
    "You changed {file}" : "Zmieniłeś {file}",
    "You changed an encrypted file in {file}" : "Zmieniłeś zaszyfrowany plik w {file}",
    "{user} changed {file}" : "{user} zmienił {file}",
    "{user} changed an encrypted file in {file}" : "{user} zmienił zaszyfrowany plik w {file}",
    "You deleted {file}" : "Usunąłeś {file}",
    "You deleted an encrypted file in {file}" : "Usunąłeś zaszyfrowany plik w {file}",
    "{user} deleted {file}" : "{user} usunął {file}",
    "{user} deleted an encrypted file in {file}" : "{user} usunął zaszyfrowany plik w {file}",
    "You restored {file}" : "Przywróciłeś {file}",
    "{user} restored {file}" : "{user} przywrócił {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Zmieniłeś {oldfile} (hidden) na {newfile} (hidden)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Zmieniłeś {oldfile} (hidden) na {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Zmieniłeś {oldfile} na {newfile} (hidden)",
    "You renamed {oldfile} to {newfile}" : "Zmieniłeś {oldfile} na {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} zmienił {oldfile} (hidden) na {newfile} (hidden)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} zmienił {oldfile} (hidden) na {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} zmienił {oldfile} na {newfile} (hidden)",
    "{user} renamed {oldfile} to {newfile}" : "{user} zmienił {oldfile} na {newfile}",
    "You moved {oldfile} to {newfile}" : "Przeniosłeś {oldfile} do {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} przeniósł {oldfile} do {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Plik został dodany lub usunięty z <strong>ulubionych</strong>",
    "A file or folder has been <strong>changed</strong>" : "Plik lub katalog został <strong>zmieniony</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Ulubiony plik lub katalog został <strong>zmieniony</strong>",
    "All files" : "Wszystkie pliki",
    "Upload (max. %s)" : "Wysyłanie (maks. %s)",
    "Accept" : "Akceptuj",
    "Reject" : "Odrzuć",
    "Incoming ownership transfer from {user}" : "Przychodzące przeniesienie własności od {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Czy chcesz zaakceptować {path}\n\nUwaga: Proces transferu po zaakceptowaniu może potrwać do 1 godziny.",
    "Ownership transfer failed" : "Przeniesienie własności nie powiodło się",
    "Your ownership transfer of {path} to {user} failed." : "Twoje przeniesienie własności {path} na {user} nie powiodło się.",
    "The ownership transfer of {path} from {user} failed." : "Przeniesienie własności {path} z {user} nie powiodło się.",
    "Ownership transfer done" : "Dokonano przeniesienia własności",
    "Your ownership transfer of {path} to {user} has completed." : "Twoje przeniesienie własności {path} na {user} zostało zakończone.",
    "The ownership transfer of {path} from {user} has completed." : "Przeniesienie własności {path} z {user} zostało zakończone.",
    "in %s" : "w %s",
    "File Management" : "Zarządzanie plikami",
    "Reload current directory" : "Przeładuj bieżący katalog",
    "Go to the \"{dir}\" directory" : "Przejdź do katalogu \"{dir}\"",
    "Select the row for {displayName}" : "Wybierz wiersz dla {displayName}",
    "Open folder {name}" : "Otwórz katalog {name}",
    "Download file {name}" : "Pobierz plik {name}",
    "\"{displayName}\" action executed successfully" : "Akcja \"{displayName}\" została wykonana pomyślnie",
    "\"{displayName}\" action failed" : "Akcja \"{displayName}\" nie powiodła się",
    "Total rows summary" : "Podsumowanie wszystkich wierszy",
    "Select all" : "Wybierz wszystko",
    "Unselect all" : "Odznacz wszystko",
    "\"{displayName}\" failed on some elements " : "\"{displayName}\" nie powiodło się w przypadku niektórych elementów",
    "\"{displayName}\" batch action executed successfully" : "Akcja wsadowa \"{displayName}\" została wykonana pomyślnie",
    "ascending" : "rosnąco",
    "descending" : "malejąco",
    "Sort list by {column} ({direction})" : "Sortuj listę według {column} ({direction})",
    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Ta lista nie jest w pełni renderowana ze względu na wydajność. Pliki będą renderowane podczas poruszania się po liście.",
    "Storage informations" : "Informacje o przechowywaniu",
    "{usedQuotaByte} used" : "Wykorzystano {usedQuotaByte}",
    "{relative}% used" : "Wykorzystano {relative}%",
    "Could not refresh storage stats" : "Nie można odświeżyć statystyk przechowywania",
    "Transfer ownership of a file or folder" : "Przenieś własność pliku lub katalogu",
    "Choose file or folder to transfer" : "Wybierz plik lub katalog do przeniesienia",
    "Change" : "Zmień",
    "New owner" : "Nowy właściciel",
    "Choose a file or folder to transfer" : "Wybierz plik lub katalog do przeniesienia",
    "Transfer" : "Przenieś",
    "Transfer {path} to {userid}" : "Przenieś {path} do {userid}",
    "Invalid path selected" : "Wybrano nieprawidłową ścieżkę",
    "Unknown error" : "Nieznany błąd",
    "Ownership transfer request sent" : "Wysłano żądanie przeniesienia własności",
    "Cannot transfer ownership of a file or folder you do not own" : "Nie można przenieść prawa własności do pliku lub katalogu, którego nie jesteś właścicielem",
    "Select file or folder to link to" : "Wybierz plik lub katalog do linku",
    "Loading current folder" : "Ładowanie bieżącego katalogu",
    "No files in here" : "Brak plików",
    "No files or folders have been deleted yet" : "Żadne pliki ani katalogi nie zostały jeszcze usunięte",
    "Go to the previous folder" : "Przejdź do poprzedniego katalogu",
    "Go back" : "Wstecz",
    "Open the files app settings" : "Otwórz ustawienia aplikacji plików",
    "Files settings" : "Ustawienia Plików",
    "File cannot be accessed" : "Nie można uzyskać dostępu do pliku",
    "You might not have have permissions to view it, ask the sender to share it" : "Możesz nie mieć uprawnień, aby go wyświetlić, poproś nadawcę o udostępnienie",
    "Show hidden files" : "Pokaż ukryte pliki",
    "Crop image previews" : "Przytnij podglądy obrazów",
    "Additional settings" : "Ustawienia dodatkowe",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Kopiuj do schowka",
    "Use this address to access your Files via WebDAV" : "Użyj tego adresu, aby uzyskać dostęp do plików poprzez WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Jeśli włączyłeś 2FA, musisz utworzyć i używać nowego hasła do aplikacji, klikając tutaj.",
    "Clipboard is not available" : "Schowek jest niedostępny",
    "WebDAV URL copied to clipboard" : "Adres URL WebDAV skopiowany do schowka",
    "Unable to change the favourite state of the file" : "Nie można zmienić ulubionego stanu pliku",
    "Error while loading the file data" : "Błąd podczas ładowania danych pliku",
    "Pick a template for {name}" : "Wybierz szablon dla {name}",
    "Cancel" : "Anuluj",
    "Create" : "Utwórz",
    "Create a new file with the selected template" : "Utwórz nowy plik z wybranym szablonem",
    "Creating file" : "Tworzenie pliku",
    "Blank" : "Pusty",
    "Unable to create new file from template" : "Nie można utworzyć nowego pliku z szablonu",
    "Delete permanently" : "Usuń bezpowrotnie",
    "Set up templates folder" : "Skonfiguruj katalog szablonów",
    "Templates" : "Szablony",
    "Unable to initialize the templates directory" : "Nie można zainicjować katalogu szablonów",
    "Toggle %1$s sublist" : "Przełącz podlistę %1$s",
    "Toggle grid view" : "Przełącz widok siatki",
    "Upload some content or sync with your devices!" : "Wyślij lub zsynchronizuj pliki z urządzeniami.",
    "No entries found in this folder" : "Brak wpisów w tym katalogu",
    "Upload too large" : "Wysyłany plik jest za duży",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Pliki, które próbujesz wysłać, przekraczają maksymalną dopuszczalną wielkość.",
    "No favorites yet" : "Brak ulubionych",
    "Files and folders you mark as favorite will show up here" : "Pliki i katalogi, które oznaczysz jako ulubione wyświetlą się tutaj",
    "Shares" : "Udostępnione",
    "Shared with others" : "Udostępnione innym",
    "Shared with you" : "Udostępnione dla Ciebie",
    "Shared by link" : "Udostępnione linkiem",
    "Deleted shares" : "Usunięte udostępnienia",
    "Pending shares" : "Oczekujące udostępnienia",
    "Text file" : "Plik tekstowy",
    "New text file.txt" : "Nowy plik tekstowy.txt",
    "Storage invalid" : "Nieprawidłowy magazyn",
    "Select" : "Wybierz",
    "You don’t have permission to upload or create files here" : "Nie masz uprawnień do wysyłania lub tworzenia plików w tym miejscu",
    "New" : "Nowy",
    "Copied!" : "Skopiowano!",
    "Unlimited" : "Brak limitu",
    "Search users" : "Wyszukaj użytkowników",
    "Cannot transfer ownership of a file or folder you don't own" : "Nie można przenieść prawa własności do pliku lub katalogu, którego nie jesteś właścicielem",
    "%s used" : "Wykorzystane: %s",
    "%s%%" : "%s%%",
    "%1$s of %2$s used" : "Wykorzystane: %1$s z %2$s",
    "Settings" : "Ustawienia",
    "Deleted files" : "Usunięte pliki"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
